==> libpqxx3_3.1.1.orig.tar.gz: libpqxx-3.1.1/doc/html/Reference/a00023.js <==
var a00023 =
[
    [ "capability", "a00023.html#a306a884246abc1051bab4fb06393ee71", [
      [ "cap_prepared_statements", "a00023.html#a306a884246abc1051bab4fb06393ee71af5a4754aea608aaf5fca6caa51c44ce0", null ],
      [ "cap_create_table_with_oids", "a00023.html#a306a884246abc1051bab4fb06393ee71aba8a02f6bb5d2304bfbf2110c6cd791a", null ],
      [ "cap_nested_transactions", "a00023.html#a306a884246abc1051bab4fb06393ee71a973dc9e4f56818f82b86fb13a5bbc405", null ],
      [ "cap_cursor_scroll", "a00023.html#a306a884246abc1051bab4fb06393ee71a8034abdbcd193f25d9d93cf79156e1fc", null ],
      [ "cap_cursor_with_hold", "a00023.html#a306a884246abc1051bab4fb06393ee71ad97556afc36aff4a62c61b67437c20c4", null ],
      [ "cap_cursor_update", "a00023.html#a306a884246abc1051bab4fb06393ee71a8ab47c10b60d6bd6664f6e88f300edcb", null ],
      [ "cap_cursor_fetch_0", "a00023.html#a306a884246abc1051bab4fb06393ee71a86380c8c083847ba3d16764784f5914f", null ],
      [ "cap_table_column", "a00023.html#a306a884246abc1051bab4fb06393ee71a1f2b785abe834490c33dc4cf19c932d2", null ],
      [ "cap_read_only_transactions", "a00023.html#a306a884246abc1051bab4fb06393ee71a01e68a67b6a3c92ce9b0c92fa73e90b2", null ],
      [ "cap_statement_varargs", "a00023.html#a306a884246abc1051bab4fb06393ee71abefe533e379346c7b9644406c613eb02", null ],
      [ "cap_prepare_unnamed_statement", "a00023.html#a306a884246abc1051bab4fb06393ee71a6b019128f2fdcfa9d316042342846e2f", null ],
      [ "cap_parameterized_statements", "a00023.html#a306a884246abc1051bab4fb06393ee71a366c98bc3385ecfb39496bf7240e5973", null ],
      [ "cap_end", "a00023.html#a306a884246abc1051bab4fb06393ee71a4a873c5d7e7fb0a9022cdd110181a7de", null ]
    ] ],
    [ "connection_base", "a00023.html#a33700cc6d830d28c3dbd48eb9b7276ab", null ],
    [ "activate", "a00023.html#a1aa330287775aa1ff83f94714f772673", null ],
    [ "adorn_name", "a00023.html#a4963aaba6da521d480c21c7ec01835cf", null ],
    [ "await_notification", "a00023.html#ab5c24029bda3198d826d24757e49c746", null ],
    [ "await_notification", "a00023.html#aa9e66faad88a94857c0749b9bbc5d352", null ],
    [ "backendpid", "a00023.html#a7179e32df28bd4bc81b85d99b36ad791", null ],
    [ "cancel_query", "a00023.html#a9709e4738b1bfb1dba547381749908cb", null ],
    [ "close", "a00023.html#af02016af0233bed748eb1ddab9685131", null ],
    [ "dbname", "a00023.html#a043e536c1923594c246f2ca8db31dffa", null ],
    [ "deactivate", "a00023.html#a10b275082e18dbcb177a8871f92c7523", null ],
    [ "disconnect", "a00023.html#a9bd21013745b4454e248e637cdae1287", null ],
    [ "esc", "a00199.html#ga8978ff727c03a1aaaa3a9d3fd3268abf", null ],
    [ "esc", "a00199.html#gae711f65dd793a70629f97a2e0e54d8db", null ],
    [ "esc", "a00199.html#gaca9ba750fd096cfd652a4323dab3a653", null ],
    [ "esc_raw", "a00199.html#ga6a8c83d3dcea7114a00c188fe6a92779", null ],
    [ "get_noticer", "a00023.html#aedf4e61e94ea58058e4bc592d98f8dc2", null ],
    [ "get_notifs", "a00023.html#aa839a066c0289a12f664e29c9dbafd38", null ],
    [ "get_variable", "a00023.html#a908a2ffdf56d8259492e9f3894e24f65", null ],
    [ "hostname", "a00023.html#a38dde9befa350a07a5ac093d13ee64e2", null ],
    [ "inhibit_reactivation", "a00023.html#aedf7ac72658efa92e702a06b1964747a", null ],
    [ "init", "a00023.html#a1d1c129c2c5797a82f251ee9dabec77e", null ],
    [ "is_open", "a00023.html#a36a26cf7e13f612749d49faf4f1654f8", null ],
    [ "perform", "a00023.html#abf3b71372850f86e4f5e67eb4b7d56bd", null ],
    [ "perform", "a00023.html#a5eac9840b79e7f1893d88b63f6d97b1d", null ],
    [ "port", "a00023.html#a826750f0f13ede4ac4e6ca8a84711b53", null ],
    [ "prepare", "a00023.html#ad2b9e50c9ebfab7c86a091cd939e1e6c", null ],
    [ "prepare", "a00023.html#af2dcc39b88897fe2bc3c5742edd43645", null ],
    [ "prepare_now", "a00023.html#a32efdc645566975851bfc7d6b82d214c", null ],
    [ "process_notice", "a00023.html#a140578ed1e1c65c61deb0407ff25959f", null ],
    [ "process_notice", "a00023.html#a9d64420154827b3572dcdb955a93bfff", null ],
    [ "protocol_version", "a00023.html#ab63e45ad783d8adb8d4a9f03e03ef6ef", null ],
    [ "quote", "a00199.html#ga81fe65fbb9561af7c5f0b33a9fe27e5a", null ],
    [ "server_version", "a00023.html#acdd295f691812773133147530aa6ff21", null ],
    [ "set_client_encoding", "a00023.html#a04895c06c5ae1d8b0863a32a28beff51", null ],
    [ "set_noticer", "a00023.html#ac6b5f32ac91993b37531e96c2d14b18e", null ],
    [ "set_variable", "a00023.html#a120b9e03dcaa9b0c3ef7026afa64d954", null ],
    [ "simulate_failure", "a00023.html#a335ca1d83e65a9e57b907c431c3afbe1", null ],
    [ "sock", "a00023.html#a8ac078b1077fbe19ee1d713bb6b71e8f", null ],
    [ "supports", "a00023.html#aefdde864e05f88e84d748236b93659e7", null ],
    [ "trace", "a00023.html#af53d2c135aa27cdb1a66ff550a26e555", null ],
    [ "unprepare", "a00023.html#a30ec51634479614b45106532e87e5dc7", null ],
    [ "username", "a00023.html#ae02522000400fc2782e892ac0387d85b", null ],
    [ "wait_read", "a00023.html#af860fe4c418cfa4f573f34d73327d111", null ],
    [ "wait_read", "a00023.html#ab8c7dd5e54493e18d5900dd70012d062", null ],
    [ "wait_write", "a00023.html#acfb8d53e6f105db280cd5d977c005bea", null ],
    [ "internal::gate::connection_dbtransaction", "a00023.html#af3dfec559fe2305e57aba653abe4c8ad", null ],
    [ "internal::gate::connection_largeobject", "a00023.html#ab15ff67d81467d271dc713b2584f1328", null ],
    [ "internal::gate::connection_notify_listener", "a00023.html#a518f718405d80def662f248b427f0e60", null ],
    [ "internal::gate::connection_parameterized_invocation", "a00023.html#a0e64dc314f291c6f81a948c59d94aa8a", null ],
    [ "internal::gate::connection_pipeline", "a00023.html#a3b9c5dc16f04600aa5415e06f6ff8fa6", null ],
    [ "internal::gate::connection_prepare_declaration", "a00023.html#a1407974cc9c548bee6d31834625c3d45", null ],
    [ "internal::gate::connection_prepare_invocation", "a00023.html#ac2eff365ba0aa25ebbf5f903ac3c7a54", null ],
    [ "internal::gate::connection_reactivation_avoidance_exemption", "a00023.html#a2247d8690958f634898bbf014a7d418c", null ],
    [ "internal::gate::connection_sql_cursor", "a00023.html#a84c1a28176815ab9103c7febec450755", null ],
    [ "internal::gate::connection_transaction", "a00023.html#a3c60c76e32687adce1e8c0dba0919773", null ]
];

==> libpqxx_4.0.1+dfsg3.orig.tar.gz: libpqxx-4.0.1+dfsg3/doc/html/Reference/a00023.js <==
var a00023 =
[
    [ "capability", "a00023.html#a306a884246abc1051bab4fb06393ee71", [
      [ "cap_prepared_statements", "a00023.html#a306a884246abc1051bab4fb06393ee71af5a4754aea608aaf5fca6caa51c44ce0", null ],
      [ "cap_create_table_with_oids", "a00023.html#a306a884246abc1051bab4fb06393ee71aba8a02f6bb5d2304bfbf2110c6cd791a", null ],
      [ "cap_nested_transactions", "a00023.html#a306a884246abc1051bab4fb06393ee71a973dc9e4f56818f82b86fb13a5bbc405", null ],
      [ "cap_cursor_scroll", "a00023.html#a306a884246abc1051bab4fb06393ee71a8034abdbcd193f25d9d93cf79156e1fc", null ],
      [ "cap_cursor_with_hold", "a00023.html#a306a884246abc1051bab4fb06393ee71ad97556afc36aff4a62c61b67437c20c4", null ],
      [ "cap_cursor_update", "a00023.html#a306a884246abc1051bab4fb06393ee71a8ab47c10b60d6bd6664f6e88f300edcb", null ],
      [ "cap_cursor_fetch_0", "a00023.html#a306a884246abc1051bab4fb06393ee71a86380c8c083847ba3d16764784f5914f", null ],
      [ "cap_table_column", "a00023.html#a306a884246abc1051bab4fb06393ee71a1f2b785abe834490c33dc4cf19c932d2", null ],
      [ "cap_read_only_transactions", "a00023.html#a306a884246abc1051bab4fb06393ee71a01e68a67b6a3c92ce9b0c92fa73e90b2", null ],
      [ "cap_statement_varargs", "a00023.html#a306a884246abc1051bab4fb06393ee71abefe533e379346c7b9644406c613eb02", null ],
      [ "cap_prepare_unnamed_statement", "a00023.html#a306a884246abc1051bab4fb06393ee71a6b019128f2fdcfa9d316042342846e2f", null ],
      [ "cap_parameterized_statements", "a00023.html#a306a884246abc1051bab4fb06393ee71a366c98bc3385ecfb39496bf7240e5973", null ],
      [ "cap_notify_payload", "a00023.html#a306a884246abc1051bab4fb06393ee71aabb5fb3d6d43442107e04e0982300d6e", null ],
      [ "cap_end", "a00023.html#a306a884246abc1051bab4fb06393ee71a4a873c5d7e7fb0a9022cdd110181a7de", null ]
    ] ],
    [ "error_verbosity", "a00023.html#a985f29750a981c8ba80bf91b22c2eee9", [
      [ "terse", "a00023.html#a985f29750a981c8ba80bf91b22c2eee9af941ee6232e0e2704c00349b8b47feff", null ],
      [ "normal", "a00023.html#a985f29750a981c8ba80bf91b22c2eee9a3e74ba2b1506b7deb1fbea2834c574cf", null ],
      [ "verbose", "a00023.html#a985f29750a981c8ba80bf91b22c2eee9aff78876e731a924c5e25b06033fced2d", null ]
    ] ],
    [ "connection_base", "a00023.html#a33700cc6d830d28c3dbd48eb9b7276ab", null ],
    [ "activate", "a00023.html#a1aa330287775aa1ff83f94714f772673", null ],
    [ "adorn_name", "a00023.html#a4963aaba6da521d480c21c7ec01835cf", null ],
    [ "await_notification", "a00023.html#ab5c24029bda3198d826d24757e49c746", null ],
    [ "await_notification", "a00023.html#aa9e66faad88a94857c0749b9bbc5d352", null ],
    [ "backendpid", "a00023.html#a7179e32df28bd4bc81b85d99b36ad791", null ],
    [ "cancel_query", "a00023.html#a9709e4738b1bfb1dba547381749908cb", null ],
    [ "close", "a00023.html#af02016af0233bed748eb1ddab9685131", null ],
    [ "dbname", "a00023.html#a043e536c1923594c246f2ca8db31dffa", null ],
    [ "deactivate", "a00023.html#a10b275082e18dbcb177a8871f92c7523", null ],
    [ "disconnect", "a00023.html#a9bd21013745b4454e248e637cdae1287", null ],
    [ "esc", "a00203.html#ga8978ff727c03a1aaaa3a9d3fd3268abf", null ],
    [ "esc", "a00203.html#gae711f65dd793a70629f97a2e0e54d8db", null ],
    [ "esc", "a00203.html#gaca9ba750fd096cfd652a4323dab3a653", null ],
    [ "esc_raw", "a00203.html#ga6a8c83d3dcea7114a00c188fe6a92779", null ],
    [ "get_errorhandlers", "a00023.html#a33280d29c4db47c1e71eb82df921691a", null ],
    [ "get_notifs", "a00023.html#aa839a066c0289a12f664e29c9dbafd38", null ],
    [ "get_variable", "a00023.html#a908a2ffdf56d8259492e9f3894e24f65", null ],
    [ "get_verbosity", "a00023.html#a4344b95a9b950a0bc07dd1f2af7bb5f0", null ],
    [ "hostname", "a00023.html#a38dde9befa350a07a5ac093d13ee64e2", null ],
    [ "inhibit_reactivation", "a00023.html#aedf7ac72658efa92e702a06b1964747a", null ],
    [ "init", "a00023.html#a1d1c129c2c5797a82f251ee9dabec77e", null ],
    [ "is_open", "a00023.html#a36a26cf7e13f612749d49faf4f1654f8", null ],
    [ "perform", "a00023.html#abf3b71372850f86e4f5e67eb4b7d56bd", null ],
    [ "perform", "a00023.html#a5eac9840b79e7f1893d88b63f6d97b1d", null ],
    [ "port", "a00023.html#a826750f0f13ede4ac4e6ca8a84711b53", null ],
    [ "prepare", "a00023.html#ab71d463277c017f695eed71cdd87afb2", null ],
    [ "prepare", "a00023.html#a2d3fc0b15713b0bba8a6a286e4e67c10", null ],
    [ "prepare_now", "a00023.html#a32efdc645566975851bfc7d6b82d214c", null ],
    [ "process_notice", "a00023.html#a140578ed1e1c65c61deb0407ff25959f", null ],
    [ "process_notice", "a00023.html#a9d64420154827b3572dcdb955a93bfff", null ],
    [ "protocol_version", "a00023.html#ab63e45ad783d8adb8d4a9f03e03ef6ef", null ],
    [ "quote", "a00203.html#ga81fe65fbb9561af7c5f0b33a9fe27e5a", null ],
    [ "quote", "a00203.html#ga7e10c6bf1796584c0949383cb25541c2", null ],
    [ "quote_name", "a00203.html#gae68c4661843dcf695585f6e1b6011788", null ],
    [ "quote_raw", "a00203.html#ga8b59e512bedb3e8a69f3aa7e557daab7", null ],
    [ "server_version", "a00023.html#acdd295f691812773133147530aa6ff21", null ],
    [ "set_client_encoding", "a00023.html#a04895c06c5ae1d8b0863a32a28beff51", null ],
    [ "set_variable", "a00023.html#a120b9e03dcaa9b0c3ef7026afa64d954", null ],
    [ "set_verbosity", "a00023.html#acfb05dee4b2d29c9a3d4925d194d5ab9", null ],
    [ "simulate_failure", "a00023.html#a335ca1d83e65a9e57b907c431c3afbe1", null ],
    [ "sock", "a00023.html#a8ac078b1077fbe19ee1d713bb6b71e8f", null ],
    [ "supports", "a00023.html#aefdde864e05f88e84d748236b93659e7", null ],
    [ "trace", "a00023.html#aafade6d46c029d62f7bb10451f7e733e", null ],
    [ "unprepare", "a00023.html#a30ec51634479614b45106532e87e5dc7", null ],
    [ "username", "a00023.html#ae02522000400fc2782e892ac0387d85b", null ],
    [ "wait_read", "a00023.html#af860fe4c418cfa4f573f34d73327d111", null ],
    [ "wait_read", "a00023.html#ab8c7dd5e54493e18d5900dd70012d062", null ],
    [ "wait_write", "a00023.html#acfb8d53e6f105db280cd5d977c005bea", null ],
    [ "internal::gate::connection_dbtransaction", "a00023.html#af3dfec559fe2305e57aba653abe4c8ad", null ],
    [ "internal::gate::connection_errorhandler", "a00023.html#aa423170b8ec82df685a1e739f53f2b14", null ],
    [ "internal::gate::connection_largeobject", "a00023.html#ab15ff67d81467d271dc713b2584f1328", null ],
    [ "internal::gate::connection_notification_receiver", "a00023.html#abbdbf8e505eb3c23680d83df6c575889", null ],
    [ "internal::gate::connection_parameterized_invocation", "a00023.html#a0e64dc314f291c6f81a948c59d94aa8a", null ],
    [ "internal::gate::connection_pipeline", "a00023.html#a3b9c5dc16f04600aa5415e06f6ff8fa6", null ],
    [ "internal::gate::connection_prepare_invocation", "a00023.html#ac2eff365ba0aa25ebbf5f903ac3c7a54", null ],
    [ "internal::gate::connection_reactivation_avoidance_exemption", "a00023.html#a2247d8690958f634898bbf014a7d418c", null ],
    [ "internal::gate::connection_sql_cursor", "a00023.html#a84c1a28176815ab9103c7febec450755", null ],
    [ "internal::gate::connection_transaction", "a00023.html#a3c60c76e32687adce1e8c0dba0919773", null ]
];
